rai\_toolbox.datasets.RestrictedImageNet
========================================

.. currentmodule:: rai_toolbox.datasets

.. autoclass:: RestrictedImageNet

   
   .. automethod:: __init__

   .. rubric:: Methods

   .. autosummary::
   
      ~RestrictedImageNet.__init__

   

   
   
   